@@ -1,23 +1,19 @@
+"""
+Example demonstrating showing functions (manipulating strings, paths, arrays)
+that are translated directly to SQL (vectorized). They don't require heavy compute,
+fetching object into cluster, etc.
+"""
+
 import datachain as dc
+from datachain import C
 from datachain.func import array, greatest, least, path, string
 
-
-def num_chars_udf(file):
-    parts = file.name.split(".")
-    if len(parts) > 1:
-        return (list(parts[1]),)
-    return ([],)
-
-
 chain = dc.read_storage("gs://datachain-demo/dogs-and-cats/", anon=True)
-chain.map(num_chars_udf, params=["file"], output={"num_chars": list[str]}).select(
-    "file.path", "num_chars"
-).show(5)
 
 (
     chain.mutate(
-        length=string.length(path.name(dc.C("file.path"))),
-        parts=string.split(path.name(dc.C("file.path")), "."),
+        length=string.length(path.name(C("file.path"))),
+        parts=string.split(path.name(C("file.path")), "."),
     )
     .select("file.path", "length", "parts")
     .show(5)
@@ -25,14 +21,14 @@ chain.map(num_chars_udf, params=["file"], output={"num_chars": list[str]}).selec
 
 (
     chain.mutate(
-        stem=path.file_stem(dc.C("file.path")),
-        ext=path.file_ext(dc.C("file.path")),
+        stem=path.file_stem(C("file.path")),
+        ext=path.file_ext(C("file.path")),
     )
     .select("file.path", "stem", "ext")
     .show(5)
 )
 
-parts = string.split(path.name(dc.C("file.path")), ".")
+parts = string.split(path.name(C("file.path")), ".")
 chain = chain.mutate(
     isdog=array.contains(parts, "dog"),
     iscat=array.contains(parts, "cat"),
@@ -46,8 +42,8 @@ chain = chain.mutate(
 
 (
     chain.mutate(
-        greatest=greatest(chain.column("a"), dc.C("b")),
-        least=least(chain.column("a"), dc.C("b")),
+        greatest=greatest(chain.column("a"), C("b")),
+        least=least(chain.column("a"), C("b")),
     )
     .select("a", "b", "greatest", "least")
     .show(10)
