@@ -97,3 +97,11 @@ class TableMissingError(DataChainError):
 
 class OutdatedDatabaseSchemaError(DataChainError):
     pass
+
+
+class CheckpointNotFoundError(NotFoundError):
+    pass
+
+
+class JobNotFoundError(NotFoundError):
+    pass
